OC.L10N.register(
    "text",
    {
    "New text document" : "Nuwe teksdokument",
    "text document" : "teksdokument",
    "Readme" : "Leesmy",
    "Text" : "Teks",
    "📝 Collaborative document editing" : "📝 Samewerkende dokumentredigering",
    "Use current version" : "Gebruik huidige weergawe",
    "Use the saved version" : "Gebruik die bewaarde weergawe",
    "Reconnect" : "Herverbind",
    "Saving …" : "Bewaar tans…",
    "Saved" : "Bewaar",
    "Last saved {lastSaved}" : "Laas bewaar {lastSaved}",
    "Unsaved changes" : "Onbewaarde veranderinge",
    "Enter your name so other users can see who is editing" : "Voer u naam in sodat andere kan weet wie hieraan werk",
    "Insert image" : "Voer beeld in",
    "Insert an image" : "Voer ’n beeld in",
    "Link file" : "Koppel lêer",
    "Select file to link to" : "Kies lêer om na te koppel",
    "Show author colors" : "Toon outeurkleure",
    "Author colors are only shown until everyone has closed the document." : "Outeurkleure word slegs getoon tot almal die dokument toegemaak het.",
    "Currently active users:" : "Gebruikers wat tans aktief is:",
    "Edit" : "Wysig",
    "Bold" : "Vet",
    "Italic" : "Skuins",
    "Strikethrough" : "Deurstreep",
    "Headings" : "Koppe",
    "Heading 1" : "Kop 1",
    "Heading 2" : "Kop 2",
    "Heading 3" : "Kop 3",
    "Heading 4" : "Kop 4",
    "Heading 5" : "Kop 5",
    "Heading 6" : "Kop 6",
    "Unordered list" : "Ongesorteerde lys",
    "Ordered list" : "Gesorteerde lys",
    "ToDo list" : "Moet-doen-lys",
    "Blockquote" : "Blokaanhaling",
    "Retry" : "Herprobeer"
},
"nplurals=2; plural=(n != 1);");
